# BLM-OdI (Blackbird Language Matrices Object Drop verb alternations in Italian)

**Authors:**  
Giuseppe Samo 1, Paola Merlo 1,2

1 Idiap Research Institute, Martigny, Switzerland

2 Department of Linguistics, University of Geneva, Switzerland


**Project / Funding:**  
DISLING/ Disentangling Linguistic Intelligence SNF Advanced grant  TMAG-1_209426 to PM

**Language:**  
Italian

**Size:**  
4.6M

**Dataset Type:**  
Synthetic dataset for object-drop alternation

**Keywords:**  
language intelligence test, synthetic data, object-drop alternation, verb alternation, verb argument structure

---

## Dataset Description

### Overview

**BLM-OdI** is a dataset developed in the **Blackbird Language Matrices** (**BLM**) framework. **BLM-OdI** is an Object-Drop (OD) alternation dataset for testing lexical semantic properties of verbs, their ability to enter or not a causative alternation. The subject in OD bears the same semantic role (Agent) in both the transitive and intransitive forms (*L'artista dipingeva la finestra*/L'artista dipingeva* `the artist painted the window`/`the artist painted`) and the verb does not have a causative meaning.

---

### Blackbird Language Matrices (BLM) Task

BLM tasks are framed as **multiple-choice problems**. Given a context of sentences, each built using specific underlying rules, the goal is to predict the next correct sentence from a set of possible answers. Each answer set consists of one correct answer and multiple incorrect (contrastive) options. Incorrect options are generated by introducing variations that violate the underlying generative rules.

For **BLM-OdI**, the focus is on modeling how Italian verbs undergo **object-drop alternation**. The dataset captures this syntactic and semantic phenomenon in sentence sequences, with answer options that either preserve or violate these rules.

---

#### Data Splits

BLM datasets also have a lexical variation dimension, to explore 
the impact of lexical variation on detecting relevant structures: 

- type I – minimal lexical variation for sentences within an instance, 
- type II – one word difference across the sentences within an instance, 
- type III – maximal lexical variation within an instance.

The data comes grouped by lexical variation (i.e. type I/II/III) and each subset is split into train/test. 
Each split contains **2140** training and **240** testing instances.



---

### Dataset Structure

The dataset is structured into CSV files, with the following columns:

- **ID**: A unique identifier for the instance.
- **Sent_{n}**: Sentences representing the context (`n` from 1 to 7).
- **Sent_template_{n}**: Chunk pattern of the sentence.
- **Sent_chunks_{n}**: The list of chunks in answer n.
- **Answer_{m}**: Possible answer sentences (`m` from 1 to 8).
- **Answer_label_{m}**: "Correct" or error type (e.g., `N1_alter`, `coordination`).
- **Answer_value_{m}**: Boolean indicating whether the option is correct or not.
- **Answer_template_{m}**: Chunk pattern of the sentence.
- **Answer_chunks_{m}**: The list of chunks in answer m.
- **Verb**: The verb used in the instance.

The dataset comes pre-split into train and test sets, and includes preprocessed json files for use with our code at [[https://github.com/CLCL-Geneva/BLM-SNFDisentangling.]]


### Evaluation

Metrics commonly used for evaluation include **accuracy**, **precision**, **recall**, and **F1-score**.

Error analysis can be performed based on the **Answer_labels**, which indicate the types of errors corresponding to each of the incorrect options in the answer set.


---

## Citation

If you use this dataset in your research, please cite the corresponding paper:

```bibtex
@inproceedings{nastase2024exploring,
  title={Exploring Italian sentence embeddings properties through multi-tasking},
  author={Vivi Nastase, Giuseppe Samo, Chunyang Jiang, Paola Merlo},
  booktitle={CLiC-it 2024: Tenth Italian Conference on Computational Linguistics},
  year={2024},
}
```


